   function [X]=mali1a(OMD,N,NS,GRAPH)
 %
 % function [X]=mali1a(OMD,N,NS,GRAPH)
 % Aliasing Problem Signal decomposition and reconstruction by DFT
 %
 % OMD- digital frequency	 X  - signal DFT
 % N  - number of values
 % NS - subsampling
 % GRAPH - graph display
 %	    (for GRAPH=1)
 %
   if exist('N')==0                      % Default values
     N=20; NS=3; oma=1.8*2*pi; TS=0.5; omd=oma*TS; GRAPH=1; end
     TNS=1/NS; n=[0:N-1]; ns=[0:TNS:N-TNS];
     f=(0:N-1)/N; f1=(0:N/2)/N; 
 %
 % Analogue function evaluation
 %
   M=N*NS; ta=[0:TNS/2:N-TNS]*TS;
   xa=cos(oma*ta);
 %
 % Discrete Fourier transform evaluation and signal reconstruction
 %
   x=cos(omd*n);
   X=fft(x);
   KZ=N*(NS-1);
   v=[X(1:N/2),zeros(1,KZ),X(N/2+1:N)];
   y=(N+KZ)/N*ifft(v);
 %
   if GRAPH~=1, return, end		% Result display
 %
   delete(get(0,'children'))  
   figure('name','MALI1A','units','normal','position',[0.29,0.01,0.7,0.8]); 
  
   subplot(221) 
      plot(ta,xa,'k'); grid on;
      axis([0,10,-1,1]);
      xlabel('Time'); 
      title('{\bf (a)} CONTINUOUS SIGNAL');

   subplot(224);
      stem(ns,real(y),':','MarkerSize',3,'Color','k'); grid on
      for k=1:N, z(k)=y((k-1)*NS+1); end
      hold on, stem(n,z,'MarkerSize',3,'Color','k'); hold off
      axis([0,20,-1,1]); 
      xlabel('Index');
      title('{\bf (d)} RECONSTRUCTED SIGNAL');

   subplot(223);
      stem(n,x,'MarkerSize',3,'Color','k'); grid on
      axis([0,20,-1,1]); 
      xlabel('Index');
      title('{\bf (b)} DISCRETE SIGNAL');

   subplot(222)
      stem(f,real(X),'MarkerSize',3,'Color','k'); grid on
      axis([0,1,-3,12]);
      xlabel('Frequency'); 
      title('{\bf (c)} REAL PART OF THE DFT');
