   function [MF]=mf1(A,N,GRAPH)
 %
 % function [MF]=mf1(A,N,GRAPH)
 % DFT of exponential sequence
 %
 % A - exponential constant	MF - matrix of modules of DFT
 % N - number of values		GRAPH - graph display (for GRAPH=1)
 %
   if exist('N')==0                 % Default values
     A=0.8; N=24; GRAPH=1; end
 %
 % Z-domain definition
 %
   [REZ,IMZ]=meshgrid(-1.1:0.1:1.1,-1.1:0.1:1.1);
   Z=(REZ+j*IMZ);
   L=abs(Z)>0.95 & abs(Z)<1.05 & rem(abs(angle(Z))+0.05,2*pi/N)<0.1;
 %
 % Z-transform and DFT evaluation
 %
   XZ=(Z.^N-A^N)./(Z.^N-A*Z.^(N-1)); XZ(12,12)=0;
   M=abs(XZ); MF=M.*L;
   RZ=real(XZ); RF=RZ.*L;
   IZ=imag(XZ); IF=IZ.*L;
 %
   if GRAPH~=1, return, end	    % Result display
 %
   delete(get(0,'children'))  
   figure('name','MF1','units','normal','position',[0.29,0.01,0.7,0.8]);  
   
    axes('position',[0.04 0.53 0.44 0.41],'xtick',[],'ytick',[],'box','on')
       title('REAL PART OF DFT')
    axes('position',[0.1 0.57 0.35 0.35]);
       mesh(real(Z),imag(Z),RF); grid on; view(68,34)
       axis([-inf +inf -inf +inf -1 3]); 
       line([-1.1 -1.1],[1.1 1.1],[-1 3],'linestyle',':','color','k');
       xlabel('Real(z)'); ylabel('Imag(z)'); 
       
    axes('position',[0.04 0.04 0.44 0.42],'xtick',[],'ytick',[],'box','on')
       title('IMAGINARY PART OF DFT')
    axes('position',[0.1 0.09 0.35 0.35]);
       mesh(real(Z),imag(Z),IF); grid on; view(68,34)
       axis([-inf +inf -inf +inf -2 2]);
       line([-1.1 -1.1],[1.1 1.1],[-1 3],'linestyle',':','color','k');
       xlabel('Real(z)'); ylabel('Imag(z)'); 
    
    axes('position',[0.52 0.04 0.40 0.9],'xtick',[],'ytick',[],'box','on')
       title('ABSOLUTE VALUE OF DFT')   
    axes('position',[0.58 0.1 0.30 0.8]);
       mesh(real(Z),imag(Z),MF); grid on; view(68,34)
       axis([-inf +inf -inf +inf 0 3]);
       line([-1.1 -1.1],[1.1 1.1],[-1 3],'linestyle',':','color','k');
       xlabel('Real(z)'); ylabel('Imag(z)'); 
       
    colormap([0 0 0])   
 