   function [W]=mlsq0(N,M,x,y,GRAPH)
 %
 % function [W]=mlsq0(N,M,x,y,GRAPH)
 % The least squares error-surface for the linear approximation
 %
 % N - number of values		W- evaluated coefficients
 %				GRAPH - graph display (for GRAPH=1)
 % M - number of basis functions
 % x - vector of independent variable
 % y - vector of dependent variable
 %
   if exist('N')==0                 % Default values
     N=5; M=2; GRAPH=1;
     x=[0.1 0.3 0.4 0.6 0.9];
     y=2+3*x+[-0.2 0.2 -0.2 0.3 -0.2]; end
 %
 % Basis definition
 %
   G=zeros(M,N);
   for i=1:M
     G(i,:)=x.^(i-1);
   end
 %
 % Coefficients evaluation
 %
   W=polyfit(x,y,M-1); W=W(M:-1:1);
 %
 % Sum of squares evaluation
 %
   W1=1:0.2:3; W2=2:0.2:4;
   for i=1:11
     for j=1:11
       WT=[W1(i),W2(j)];
       Z(j,i)=[(y-WT*G)]*[(y-WT*G)]'; end
   end
 %
   if GRAPH~=1, return, end	    % Result display
 %
   delete(get(0,'children'))  
   figure('name','MLSQ0','units','normal','position',[0.29,0.01,0.7,0.8]);  
   
   axes('position',[0.04 0.1 0.44 0.85],'xtick',[],'ytick',[],'box','on')
      title('ERROR-SURFACE')
   axes('position',[0.1 0.2 0.35 0.65]);
      ZZ=zeros(13,13); ZZ(2:12,2:12)=Z;
      mesh(ZZ); grid on; 
      axis([0 14 0 14 -inf 12]);
      line([0 14],[14 14],[12 12],'linestyle',':','color','k');
      line([14 14],[0 14],[12 12],'linestyle',':','color','k');
      line([14 14],[14 14],[0 12],'linestyle',':','color','k');
      xlabel('W1');
      ylabel('W2');
       
   axes('position',[0.58 0.6 0.37 0.35]);
      axis([0 1 0 5]);
      stem(x,y,'MarkerSize',3,'Color','k'); grid on; hold on
      plot(x,W(1)+W(2)*x','-*'); hold off
      text(0.5,4.2,'y(n)'); 
      text(0.63,3.7,'f(x(n))');
      text(0.66,-0.5,'x(n)');
      title('APPROXIMATION');
     
   axes('position',[0.58 0.1 0.37 0.35]);
      contour(W1,W2,Z,20,'Color','k'); grid on
      title('ERROR-SURFACE CONTOUR PLOT')
      xlabel('Coefficient W1')
      ylabel('Coefficient W2')
