   function [WW]=mlsq12(N,DELTA,EPS,M,W,x,y,GRAPH)
 %
 % function [WW]=mlsq12(N,DELTA,EPS,M,W,x,y,GRAPH)
 % Gradient search with gradient evaluated for the whole set of input values
 % for nonorthogonal basis sequence and for its updating after for each input
 % value
 % 
 % N - number of values		W - vector of last coefficients
 % DELTA - gradient constant	WW- matrix of coefficients and gradients
 % EPS	- limit value		GRAPH - graph display (for GRAPH=1)
 % M - number of basis functions
 % W - initial coefficients estimate
 % x - vector of independent variable
 % y - vector of dependent variable
 %
   if exist('N')==0                 % Default values
     N=50;EPS=0.0001; GRAPH=1;
     M=2; DELTA=0.01; GAMMA=0.6;  end
   rand('seed',0); x=rand(1,N);
   y=2+3*x+0.1*rand(1,N)-0.05;
   W=[1.5 2]; WW=[W,W]; S=[1.5 2]; SS=[S,S];
 %
 % Basis definition
 %
   G=zeros(M,N);
   for i=1:M
     G(i,:)=x.^(i-1);
   end
 %
 % Weights updating with gradient evaluation 
 %
   for n=1:N-1
     GR=-(y-W*G)*G';                            % Gradient evaluation
     if max(abs(GR))<EPS,DELTA=DELTA/2;end
     W=W-DELTA*GR; WW=[WW;[W,GR]];
   end
 %
 % Weights updating with gradient updating for each input value
 %
   for n=1:N-1
     E(n)=y(n)-S*G(:,n); GR=-E(n)*G(:,n)';       % Gradient estimation
     if max(abs(GR))<EPS,GAMMA=GAMMA/2;end
     S=S-GAMMA*GR; SS=[SS;[S,GR]];
   end
 %
 % Sum of squares evaluation
 %
   W1=1:0.2:3; W2=2:0.2:4;
   for i=1:11
     for j=1:11
       WT=[W1(i),W2(j)];
       Z(j,i)=[(y-WT*G)]*[(y-WT*G)]'; end
   end
 %
   if GRAPH~=1, return, end	    % Result display
 %

   delete(get(0,'children'))  
   figure('name','MLSQ12','units','normal','position',[0.29,0.01,0.7,0.8]); 
   
   axes('position',[0.04 0.1 0.44 0.85],'xtick',[],'ytick',[],'box','on')
      title('ERROR-SURFACE')
   axes('position',[0.1 0.2 0.35 0.65]);
      ZZ=zeros(13,13); ZZ(2:12,2:12)=Z;
      mesh(ZZ); grid on; 
      axis([0 14 0 14 -inf 150]);
      line([14 14],[14 14],[0 150],'linestyle',':','color','k');
      xlabel('W1');
      ylabel('W2');
       
   axes('position',[0.58 0.6 0.37 0.35]);
      contour(W1,W2,Z,20); grid on; hold on;
      plot(WW(:,1),WW(:,2)); hold off;
      title('Gradient Evaluation')
      xlabel('Coefficient W1')
      ylabel('Coefficient W2')

   axes('position',[0.58 0.1 0.37 0.35]);
      contour(W1,W2,Z,20); grid on; hold on; 
      plot(SS(:,1),SS(:,2)); hold off;
      title('GRADIENT ESTIMATION')
      xlabel('Coefficient W1')
      ylabel('Coefficient W2')
