   function [W]=mlsqort(N,M,x,y,GRAPH)
 %
 % function [W]=mlsqort(N,M,x,y,GRAPH)
 % The least squares error-surface for the linear approximation and
 % for an orthogonal basis sequence
 %
 % N - number of values		W - vector of last coefficients
 %				GRAPH - graph display (for GRAPH=1)
 % M - number of basis functions
 % x - vector of independent variable
 % y - vector of dependent variable
 %
   if exist('N')==0                 % Default values
     N=5; M=2; GRAPH=1;
   x=[0.1 0.3 0.4 0.6 0.9];
   y=2+3*(x-mean(x))+[-0.2 0.2 -0.2 0.3 -0.2]; end
 %
 % Basis definition
 %
   G(1,:)=ones(1,N);
   LAMBDA=mean(x); G(2,:)=x-LAMBDA;
 %   ...;	    G(3,:)= ...;
 %   ...........................
 %
 % Coefficient evaluation
 %
   W=(y*G')./diag(G*G')';
 %
 % Sum of squares evaluation
 %
   W1=1:0.1:3; W2=2:0.1:4;
   for i=1:21
     for j=1:21
       WT=[W1(i),W2(j)];
       Z(j,22-i)=[(y-WT*G)]*[(y-WT*G)]'; end
   end
 %
   if GRAPH~=1, return, end	    % Result display
 %
   delete(get(0,'children'))  
   figure('name','MLSQORT','units','normal','position',[0.29,0.01,0.7,0.8]);  
  
   axes('position',[0.04 0.1 0.44 0.85],'xtick',[],'ytick',[],'box','on')
      title('ERROR SURFACE');
   axes('position',[0.1 0.2 0.35 0.65]);
      ZZ=zeros(23,23); ZZ(2:22,2:22)=Z;
      mesh(ZZ); grid on;
      xlabel('W1'); 
      ylabel('W2');
  
   axes('position',[0.58 0.1 0.40 0.85]); 
      contour(W1,W2,Z,20); grid on
      title('ERROR-SURFACE CONTOUR PLOT')
      xlabel('Coefficient W1')
      ylabel('Coefficient W2')
