   function [WW]=mlsqsig(N,DELTA,EPS,M,W,x,y,GRAPH)
 %
 % function [WW]=mlsqsig(N,DELTA,EPS,M,W,x,y,GRAPH)
 % Gradient search with gradient updated after each value
 %
 % N - number of values		W - vector of last coefficients
 % DELTA - gradient constant	WW- matrix of coefficients and gradients
 % EPS	- limit value		GRAPH - graph display (for GRAPH=1)
 % M - number of basis functions
 % W - initial coefficients estimate
 % x - vector of independent variable
 % y - vector of dependent variable
 %
   if exist('N')==0                 % Default values
     N=50;EPS=0.001; GRAPH=1;
     M=2; DELTA=0.6;
   rand('seed',0); x=rand(N,1);
   G=[x(2:N), x(1:N-1)];
   y=G*[2 3]'+0.1*rand(N-1,1)-0.05;
   W=[1.5 2]'; WW=W; end
 %
 % Weights updating
 %
   for n=1:N-1
     E(n)=y(n)-G(n,:)*W; GR=-2*E(n)*G(n,:)';       % Gradient estimation
     if max(abs(GR))<EPS,DELTA=DELTA/2;end
     W=W-DELTA*GR; WW=[WW,W];
     f(n)=G(n,:)*W;
   end
 %
 % Sum of squares evaluation
 %
   W1=1:0.2:3; W2=2:0.2:4;
   for i=1:11
     for j=1:11
       WT=[W1(i),W2(j)]';
       Z(j,i)=[(y-G*WT)]'*[(y-G*WT)]; end
   end
 %
   if GRAPH~=1, return, end	    % Result display
 %
   delete(get(0,'children'))  
   figure('name','MLSQSIG','units','normal','position',[0.24,0.11,0.7,0.8]); 

   subplot(221); 
      plot([1:N-1;1:N-1],[x(2:N)';zeros(1,N-1)],'-k'); grid on;
      axis([0 N 0 1]);
      xlabel('Index');
      title('SEQUENCE {\it \{x(n)\}}');
   
   subplot(223);
      plot([1:N-1;1:N-1],[y';zeros(1,N-1)],'-k'); hold on; 
      plot(f,':'); grid on; hold off;
      axis([0 N 0 5]);
      xlabel('Index');
      title('SEQUENCE {\it \{y(n)\}}');
  
   subplot(122)
      contour(W1,W2,Z,20); grid on; hold on;
      plot(WW(1,:),WW(2,:)); hold off;
      title('GRADIENT SEARCH')
      xlabel('Coefficient W1')
      ylabel('Coefficient W2')
  